==> common-2.0.0-sources.jar: cn/gtmap/gtc/resource/Constant.java <==
package cn.gtmap.gtc.resource;

/**
 * .Constant
 *
 * @author <a href="mailto:lanxy88@gmail.com">NelsonXu</a>
 * @version V1.0, 2017/9/21 11:36
 */
public final class Constant {

    public static final String DEFAULT_RESOURCE_CATALOG = "RESC";
    public static final String DEFAULT_RESOURCE_TYPE = "REST";
    public static final String DEFAULT_XZZJG_CATALOG = "XZJG";
    public static final String DEFAULT_ZBXT_CATALOG = "ZBXT";
    public static final String DEFAULT_WDLX_CATALOG = "WDLX";

    /**
     * 文件后缀
     */
    public static final String SUFFIX_SHP = ".shp";

    public static final String SUFFIX_ZIP = ".zip";

    public static final String SUFFIX_CPG = ".cpg";

    /**
     * 数据集名称
     */
    public static final String CHARSET_GBK = "gbk";

    public static final String CHARSET_UTF8 = "utf-8";

    /**
     * 分页
     */
    public static final String PAGE = "page";

    public static final String SIZE = "size";

    /**
     * 数字（字符串）
     */
    public static final String STR_ZERO = "0";

    public static final String STR_ONE = "1";

    public static final String STR_TWO = "2";

    public static final String STR_THREE = "3";

    public static final String STR_FOUR = "4";

    public static final String STR_FIVE = "5";

    /**
     * 布尔值（字符串）
     */
    public static final String STR_TRUE = "true";

    public static final String STR_FALSE = "false";

    /**
     * 数字（整形）
     */
    public static final int NUM_ZERO = 0;

    public static final int NUM_ONE = 1;

    public static final int NUM_TWO = 2;

    public static final int NUM_THREE = 3;

    public static final int NUM_FOUR = 4;

    public static final int NUM_FIVE = 5;

    /**
     * 特殊符号
     */
    public static final String EN_EQUAL = "=";

    public static final String EN_FULL_STOP = ".";

    public static final String EN_QUESTION_MARK = "?";

    public static final String EN_COMMA = ",";

    public static final String EN_URL_CONNECTOR = "&";

    public static final String EN_COLON = ":";

    public static final String EN_FORWARD_SLASH = "/";

    public static final String EN_BACK_SLASH = "\\";

    public static final String EN_LEFT_BRACE = "{";

    public static final String EN_RIGHT_BRACE = "}";

    public static final String EN_SINGLE_QUOTE = "'";

    public static final String EN_DOUBLE_QUOTE = "\"";

    /**
     * MIME常见类型
     */
    public static final String MIME_TYPE_IMAGE_PNG = "image/png";

    public static final String MIME_TYPE_ZIP = "application/zip";

    public static final String MIME_TYPE_JSON = "application/json";

    /**
     * Map初始化大小
     */
    public static final int MAP_SIZE_SMALL = 5;

    public static final int MAP_SIZE_DEFAULT = 16;

    /**
     * 默认日期格式
     */
    public static final String DEFAULT_DATE_FORMATE = "yyyy-MM-dd";

    /**
     * 默认日期时间格式
     */
    public static final String DEFAULT_DATETIME_FORMATE = "yyyy-MM-dd HH:mm:ss";

    /**
     *
     */
    public static final String ACCESS_CONTROL_ALLOW_ORIGN = "Access-Control-Allow-Origin";

    /**
     * 省、市、区、县
     */

    public static final Integer PROVINCE = 2;

    public static final Integer CITY = 4;

    public static final Integer AREA = 6;

    public static final String MSG = "message";

    public static final String RESULT = "result";

    /**
     * 加密解密的key
     */
    public static final String KEY = "123456";

    /**
     * 资源共享类型
     */

    public static final String UNCONDITIONAL = "1";

    public static final String CONDITIONAL = "2";

    public static final String NOTSHARE = "3";


    private Constant() {

    }

}

==> common-2.0.2-sources.jar: cn/gtmap/gtc/resource/Constant.java <==
package cn.gtmap.gtc.resource;

/**
 * .Constant
 *
 * @author <a href="mailto:lanxy88@gmail.com">NelsonXu</a>
 * @version V1.0, 2017/9/21 11:36
 */
public final class Constant {

    public static final String DEFAULT_RESOURCE_CATALOG = "RESC";
    public static final String DEFAULT_RESOURCE_TYPE = "REST";
    public static final String DEFAULT_XZZJG_CATALOG = "XZJG";
    public static final String DEFAULT_ZBXT_CATALOG = "ZBXT";
    public static final String DEFAULT_WDLX_CATALOG = "WDLX";
    public static final String DEFAULT_ZTLX_CATALOG = "ZTLX";

    /**
     * 文件后缀
     */
    public static final String SUFFIX_SHP = ".shp";

    public static final String SUFFIX_ZIP = ".zip";

    public static final String SUFFIX_CPG = ".cpg";

    /**
     * 数据集名称
     */
    public static final String CHARSET_GBK = "gbk";

    public static final String CHARSET_UTF8 = "utf-8";

    /**
     * 分页
     */
    public static final String PAGE = "page";

    public static final String SIZE = "size";

    /**
     * 数字（字符串）
     */
    public static final String STR_ZERO = "0";

    public static final String STR_ONE = "1";

    public static final String STR_TWO = "2";

    public static final String STR_THREE = "3";

    public static final String STR_FOUR = "4";

    public static final String STR_FIVE = "5";

    /**
     * 布尔值（字符串）
     */
    public static final String STR_TRUE = "true";

    public static final String STR_FALSE = "false";

    /**
     * 数字（整形）
     */
    public static final int NUM_ZERO = 0;

    public static final int NUM_ONE = 1;

    public static final int NUM_TWO = 2;

    public static final int NUM_THREE = 3;

    public static final int NUM_FOUR = 4;

    public static final int NUM_FIVE = 5;

    /**
     * 特殊符号
     */
    public static final String EN_EQUAL = "=";

    public static final String EN_FULL_STOP = ".";

    public static final String EN_QUESTION_MARK = "?";

    public static final String EN_COMMA = ",";

    public static final String EN_URL_CONNECTOR = "&";

    public static final String EN_COLON = ":";

    public static final String EN_FORWARD_SLASH = "/";

    public static final String EN_BACK_SLASH = "\\";

    public static final String EN_LEFT_BRACE = "{";

    public static final String EN_RIGHT_BRACE = "}";

    public static final String EN_SINGLE_QUOTE = "'";

    public static final String EN_DOUBLE_QUOTE = "\"";

    /**
     * MIME常见类型
     */
    public static final String MIME_TYPE_IMAGE_PNG = "image/png";

    public static final String MIME_TYPE_ZIP = "application/zip";

    public static final String MIME_TYPE_JSON = "application/json";

    public static final String MIME_TYPE_PDF = "application/pdf";

    /**
     * Map初始化大小
     */
    public static final int MAP_SIZE_SMALL = 5;

    public static final int MAP_SIZE_DEFAULT = 16;

    /**
     * 默认日期格式
     */
    public static final String DEFAULT_DATE_FORMATE = "yyyy-MM-dd";

    /**
     * 默认日期时间格式
     */
    public static final String DEFAULT_DATETIME_FORMATE = "yyyy-MM-dd HH:mm:ss";

    /**
     *
     */
    public static final String ACCESS_CONTROL_ALLOW_ORIGN = "Access-Control-Allow-Origin";

    /**
     * 省、市、区、县
     */

    public static final Integer PROVINCE = 2;

    public static final Integer CITY = 4;

    public static final Integer AREA = 6;

    public static final String MSG = "message";

    public static final String RESULT = "result";

    /**
     * 加密解密的key
     */
    public static final String KEY = "123456";

    /**
     * 资源共享类型
     */

    public static final String UNCONDITIONAL = "1";

    public static final String CONDITIONAL = "2";

    public static final String NOTSHARE = "3";

    /**
     * 流程状态
     */
    public static final String UNCHECKED = "unchecked";
    public static final String CHECKED = "checked";
    public static final String TURN_BACK = "turnBack";
    /**
     * 默认审批管理员
     */
    public static final String DATAADMIN = "dataAdmin";

    /**
     * 申请审批数据类型
     */
    public static final String DATA_RES = "resource";
    public static final String DATA_TRANSFER = "dataTransfer";
    public static final String DATA_APPLY = "dataApply";
    public static final String DATA_REPAIR = "dataRepair";

    /**
     *  短信发送方式
     */
    public static final String ALI = "ali";
    public static final String MSG_HTTP = "http";

    public static final String MOBILE = "mobile";

    private Constant() {

    }

}
